#include <VirtualWire.h>
#include <Bounce.h>
#include <AnalogSmooth.h>

int leftArm;
int rightArm;
int leftKnee;
int rightKnee;
int chestPush;

AnalogSmooth as1 = AnalogSmooth(5);
AnalogSmooth as2 = AnalogSmooth(5);
AnalogSmooth as3 = AnalogSmooth(5);
AnalogSmooth as4 = AnalogSmooth(5);


Bounce chestPushButton = Bounce(A5, 10);

char sendMessage[27];

void setup() {
  // Sensors
  pinMode(A9,INPUT);
  pinMode(A8,INPUT);
  pinMode(A3,INPUT);
  pinMode(A6,INPUT);
  pinMode(19,INPUT_PULLUP);

  pinMode(14,OUTPUT);

  // VirtualWire setup
  vw_set_ptt_inverted(true);
  vw_setup(4800);
  vw_set_tx_pin(14);
}

byte previousState = HIGH;
unsigned int count = 0;
unsigned long countAt = 0; 
unsigned int countPrinted = 0; 

void loop() {
  leftArm = as1.analogReadSmooth(A9);
  rightArm = as2.analogReadSmooth(A8);
  leftKnee = as3.analogReadSmooth(A3);
  rightKnee = as4.analogReadSmooth(A6);
  
  if (chestPushButton.update()) {
    if (chestPushButton.fallingEdge()) {
      count = count + 1;
      countAt = millis();
    }
  } else {
    if (count != countPrinted) {
      unsigned long nowMillis = millis();
      if (nowMillis - countAt > 10) {
        countPrinted = count;
        chestPush = 80;
      }
    } else {
        chestPush = 0;
      }
  }  
    
  sprintf(sendMessage, "%d,%d,%d,%d,%d", leftArm, rightArm, leftKnee, rightKnee, chestPush);
  Serial.print("Sent Message: ");
  Serial.println(sendMessage);

  vw_send((uint8_t *)sendMessage, strlen(sendMessage));
  vw_wait_tx();
  delay(5);
}

